# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.circular_orbit import CircularOrbit

class TestCircularOrbit(unittest.TestCase):
    """CircularOrbit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CircularOrbit:
        """Test CircularOrbit
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CircularOrbit`
        """
        model = CircularOrbit()
        if include_optional:
            return CircularOrbit(
                inclination = 1.337,
                parameters = orbital_transfer.models.circular_orbit_parameters.CircularOrbitParameters(),
                advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                    orbit_date = '', 
                    ascending_node_type = 'RAAN', 
                    raan = 1.337, 
                    mltan = 1.337, 
                    anomaly = 1.337, 
                    anomaly_type = 'TRUE', 
                    orbital_element_type = 'MEAN', 
                    perigee_argument = 1.337, )
            )
        else:
            return CircularOrbit(
        )
        """

    def testCircularOrbit(self):
        """Test CircularOrbit"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
