# coding: utf-8

# flake8: noqa
"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from orbital_transfer.models.advanced_orbit_parameters import AdvancedOrbitParameters
from orbital_transfer.models.analytical_orbital_transfer_request import AnalyticalOrbitalTransferRequest
from orbital_transfer.models.analytical_orbital_transfer_request_drag_perturbation import AnalyticalOrbitalTransferRequestDragPerturbation
from orbital_transfer.models.analytical_orbital_transfer_response import AnalyticalOrbitalTransferResponse
from orbital_transfer.models.atmospheric_model import AtmosphericModel
from orbital_transfer.models.axis import Axis
from orbital_transfer.models.body_solar_array import BodySolarArray
from orbital_transfer.models.box_spacecraft_geometry import BoxSpacecraftGeometry
from orbital_transfer.models.cartesian_ephemerides import CartesianEphemerides
from orbital_transfer.models.circular_altitude_orbit_parameters import CircularAltitudeOrbitParameters
from orbital_transfer.models.circular_ground_track_repeated_orbit_parameters import CircularGroundTrackRepeatedOrbitParameters
from orbital_transfer.models.circular_orbit import CircularOrbit
from orbital_transfer.models.circular_orbit_parameters import CircularOrbitParameters
from orbital_transfer.models.custom_maneuvering_strategy import CustomManeuveringStrategy
from orbital_transfer.models.deployable_fixed_solar_array import DeployableFixedSolarArray
from orbital_transfer.models.deployable_rotating_solar_array import DeployableRotatingSolarArray
from orbital_transfer.models.drag_perturbation import DragPerturbation
from orbital_transfer.models.duty_cycle_thrust_arc_definition import DutyCycleThrustArcDefinition
from orbital_transfer.models.earth_potential_perturbation import EarthPotentialPerturbation
from orbital_transfer.models.elliptical_ground_track_repeated_eccentricity_orbit_parameters import EllipticalGroundTrackRepeatedEccentricityOrbitParameters
from orbital_transfer.models.elliptical_orbit import EllipticalOrbit
from orbital_transfer.models.elliptical_orbit_parameters import EllipticalOrbitParameters
from orbital_transfer.models.elliptical_perigee_alt_apogee_alt_orbit_parameters import EllipticalPerigeeAltApogeeAltOrbitParameters
from orbital_transfer.models.elliptical_perigee_alt_eccentricity_orbit_parameters import EllipticalPerigeeAltEccentricityOrbitParameters
from orbital_transfer.models.elliptical_sma_eccentricity_orbit_parameters import EllipticalSmaEccentricityOrbitParameters
from orbital_transfer.models.geostationary_orbit import GeostationaryOrbit
from orbital_transfer.models.harris_priester_atmospheric_model import HarrisPriesterAtmosphericModel
from orbital_transfer.models.keplerian_ephemerides import KeplerianEphemerides
from orbital_transfer.models.mean_or_osculating_spacecraft_states import MeanOrOsculatingSpacecraftStates
from orbital_transfer.models.mean_or_osculating_spacecraft_states_attitude import MeanOrOsculatingSpacecraftStatesAttitude
from orbital_transfer.models.mean_or_osculating_spacecraft_states_pv_coordinates import MeanOrOsculatingSpacecraftStatesPvCoordinates
from orbital_transfer.models.nrlmsise00_atmospheric_model import NRLMSISE00AtmosphericModel
from orbital_transfer.models.orbit import Orbit
from orbital_transfer.models.orbital_transfer_simulation_request import OrbitalTransferSimulationRequest
from orbital_transfer.models.orbital_transfer_simulation_request_inputs import OrbitalTransferSimulationRequestInputs
from orbital_transfer.models.orbital_transfer_simulation_request_outputs import OrbitalTransferSimulationRequestOutputs
from orbital_transfer.models.orbital_transfer_simulation_request_outputs_orbital_ephemerides import OrbitalTransferSimulationRequestOutputsOrbitalEphemerides
from orbital_transfer.models.orbital_transfer_simulation_request_outputs_spacecraft_states import OrbitalTransferSimulationRequestOutputsSpacecraftStates
from orbital_transfer.models.orbital_transfer_simulation_request_outputs_thrust_ephemerides import OrbitalTransferSimulationRequestOutputsThrustEphemerides
from orbital_transfer.models.orbital_transfer_simulation_response import OrbitalTransferSimulationResponse
from orbital_transfer.models.orbital_transfer_simulation_response_field_indexes_inner import OrbitalTransferSimulationResponseFieldIndexesInner
from orbital_transfer.models.orbital_transfer_simulation_response_orbital_ephemerides import OrbitalTransferSimulationResponseOrbitalEphemerides
from orbital_transfer.models.orbital_transfer_simulation_response_orbital_ephemerides_mean import OrbitalTransferSimulationResponseOrbitalEphemeridesMean
from orbital_transfer.models.orbital_transfer_simulation_response_orbital_ephemerides_osculating import OrbitalTransferSimulationResponseOrbitalEphemeridesOsculating
from orbital_transfer.models.orbital_transfer_simulation_response_results import OrbitalTransferSimulationResponseResults
from orbital_transfer.models.orbital_transfer_simulation_response_spacecraft_states import OrbitalTransferSimulationResponseSpacecraftStates
from orbital_transfer.models.orbital_transfer_simulation_response_spacecraft_states_thrusting_inner import OrbitalTransferSimulationResponseSpacecraftStatesThrustingInner
from orbital_transfer.models.orbital_transfer_simulation_response_thrust_ephemerides import OrbitalTransferSimulationResponseThrustEphemerides
from orbital_transfer.models.perturbation import Perturbation
from orbital_transfer.models.platform import Platform
from orbital_transfer.models.propulsion_system import PropulsionSystem
from orbital_transfer.models.solar_array import SolarArray
from orbital_transfer.models.solar_array_face import SolarArrayFace
from orbital_transfer.models.spacecraft_geometry import SpacecraftGeometry
from orbital_transfer.models.spacecraft_geometry_dimension import SpacecraftGeometryDimension
from orbital_transfer.models.spherical_spacecraft_geometry import SphericalSpacecraftGeometry
from orbital_transfer.models.srp_perturbation import SrpPerturbation
from orbital_transfer.models.third_body_perturbation import ThirdBodyPerturbation
from orbital_transfer.models.thrust_arc_definition import ThrustArcDefinition
from orbital_transfer.models.thrust_arcs_positions import ThrustArcsPositions
from orbital_transfer.models.thrust_duration_thrust_arc_definition import ThrustDurationThrustArcDefinition
