# coding: utf-8

"""
    Orbital transfer API

    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   <b>CHANGELOG</b> <ul>   <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>   <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>   <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li> </ul> 

    The version of the OpenAPI document: 2.2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "orbital-transfer"
VERSION = "2.2.0"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Orbital transfer API",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Orbital transfer API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Exotrail",
    long_description_content_type='text/markdown',
    long_description="""\
    An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed.  When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is  less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle.   Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag  and solar radiation pressure.   &lt;b&gt;CHANGELOG&lt;/b&gt; &lt;ul&gt;   &lt;li&gt;&lt;b&gt;2.2.0&lt;/b&gt; - 2024-07-11 - Add space weather data source choice to &lt;b&gt;NRLMSISE00AtmosphericModel&lt;/b&gt; schema&lt;/li&gt;   &lt;li&gt;&lt;b&gt;2.1.0&lt;/b&gt; - 2024-07-03 - Add &lt;b&gt;atmosphericModel&lt;/b&gt; in &lt;b&gt;DragPerturbation&lt;/b&gt; schema&lt;/li&gt;   &lt;li&gt;&lt;b&gt;2.0.0&lt;/b&gt; - 2024-06-06 - Complete refactoring of the API&lt;/li&gt; &lt;/ul&gt; 
    """,  # noqa: E501
    package_data={"orbital_transfer": ["py.typed"]},
)
